==> jc-1.4.0.tar.gz: gnu/java/nio/charset/US__5fASCII.h <==
// final class gnu.java.nio.charset.US_ASCII

// class file dependencies
// @dep_class f3ad3fa3b1ca5f55 gnu_java_nio_charset_US__5fASCII
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a594354b5ffbd332 java_nio_charset_Charset

// header file dependencies
// @dep_header java_nio_charset_Charset

#include "java/nio/charset/Charset.h"

#ifndef _JC_gnu_java_nio_charset_US__5fASCII_H_
#define _JC_gnu_java_nio_charset_US__5fASCII_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CharsetDecoder$object;
struct _jc_java_nio_charset_CharsetEncoder$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_US__5fASCII$sub_refs	_jc_gnu_java_nio_charset_US__5fASCII$sub_refs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII$sub_nonrefs	_jc_gnu_java_nio_charset_US__5fASCII$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII$refs	_jc_gnu_java_nio_charset_US__5fASCII$refs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII$nonrefs	_jc_gnu_java_nio_charset_US__5fASCII$nonrefs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII$object	_jc_gnu_java_nio_charset_US__5fASCII$object;

typedef const struct _jc_gnu_java_nio_charset_US__5fASCII$vmethods	_jc_gnu_java_nio_charset_US__5fASCII$vmethods;
typedef const struct _jc_gnu_java_nio_charset_US__5fASCII$vtable	_jc_gnu_java_nio_charset_US__5fASCII$vtable;
typedef const struct _jc_gnu_java_nio_charset_US__5fASCII$vtype	_jc_gnu_java_nio_charset_US__5fASCII$vtype;

// Constructors
extern void _jc_gnu_java_nio_charset_US__5fASCII$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *);

// Virtual methods
extern jboolean _jc_gnu_java_nio_charset_US__5fASCII$method$contains$6dc00deccaf89e6e(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *, struct _jc_java_nio_charset_Charset$object *);
extern struct _jc_java_nio_charset_CharsetDecoder$object *_jc_gnu_java_nio_charset_US__5fASCII$method$newDecoder$a8155f7e01d3e07a(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *);
extern struct _jc_java_nio_charset_CharsetEncoder$object *_jc_gnu_java_nio_charset_US__5fASCII$method$newEncoder$d60e26d796f39211(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_US__5fASCII$method_info$contains$6dc00deccaf89e6e;
extern _jc_method _jc_gnu_java_nio_charset_US__5fASCII$method_info$newDecoder$a8155f7e01d3e07a;
extern _jc_method _jc_gnu_java_nio_charset_US__5fASCII$method_info$newEncoder$d60e26d796f39211;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_US__5fASCII$vmethods {
	jboolean	(*contains$6dc00deccaf89e6e)(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *, struct _jc_java_nio_charset_Charset$object *);
	struct _jc_java_nio_charset_CharsetDecoder$object	*(*newDecoder$a8155f7e01d3e07a)(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *);
	struct _jc_java_nio_charset_CharsetEncoder$object	*(*newEncoder$d60e26d796f39211)(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *);
};

// Vtable
struct _jc_gnu_java_nio_charset_US__5fASCII$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_Charset$vmethods	java_nio_charset_Charset;
	_jc_gnu_java_nio_charset_US__5fASCII$vmethods	gnu_java_nio_charset_US__5fASCII;
};

// Vtype
struct _jc_gnu_java_nio_charset_US__5fASCII$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_US__5fASCII$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_US__5fASCII$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_US__5fASCII$refs {
    _jc_gnu_java_nio_charset_US__5fASCII$sub_refs	gnu_java_nio_charset_US__5fASCII;
    _jc_java_nio_charset_Charset$sub_refs	java_nio_charset_Charset;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_US__5fASCII$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_US__5fASCII$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_Charset$sub_nonrefs	java_nio_charset_Charset;
    _jc_gnu_java_nio_charset_US__5fASCII$sub_nonrefs	gnu_java_nio_charset_US__5fASCII;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_US__5fASCII$object {
	_jc_gnu_java_nio_charset_US__5fASCII$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_US__5fASCII$vtype	*vtype;
	_jc_gnu_java_nio_charset_US__5fASCII$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_US__5fASCII$vtype _jc_gnu_java_nio_charset_US__5fASCII$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_US__5fASCII, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_US__5fASCII$class_object;

#endif	/* _JC_gnu_java_nio_charset_US__5fASCII_H_ */

==> jc-1.4.5.tar.gz: gnu/java/nio/charset/US__5fASCII.h <==
// final class gnu.java.nio.charset.US_ASCII

// class file dependencies
// @dep_class f3ad3fa3b1ca5f55 gnu_java_nio_charset_US__5fASCII
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4793f288d91002f4 java_nio_charset_Charset

// header file dependencies
// @dep_header java_nio_charset_Charset

#include "java/nio/charset/Charset.h"

#ifndef _JC_gnu_java_nio_charset_US__5fASCII_H_
#define _JC_gnu_java_nio_charset_US__5fASCII_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CharsetDecoder$object;
struct _jc_java_nio_charset_CharsetEncoder$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_US__5fASCII$sub_refs	_jc_gnu_java_nio_charset_US__5fASCII$sub_refs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII$sub_nonrefs	_jc_gnu_java_nio_charset_US__5fASCII$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII$refs	_jc_gnu_java_nio_charset_US__5fASCII$refs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII$nonrefs	_jc_gnu_java_nio_charset_US__5fASCII$nonrefs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII$object	_jc_gnu_java_nio_charset_US__5fASCII$object;

typedef const struct _jc_gnu_java_nio_charset_US__5fASCII$vmethods	_jc_gnu_java_nio_charset_US__5fASCII$vmethods;
typedef const struct _jc_gnu_java_nio_charset_US__5fASCII$vtable	_jc_gnu_java_nio_charset_US__5fASCII$vtable;
typedef const struct _jc_gnu_java_nio_charset_US__5fASCII$vtype	_jc_gnu_java_nio_charset_US__5fASCII$vtype;

// Constructors
extern void _jc_gnu_java_nio_charset_US__5fASCII$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_nio_charset_US__5fASCII$method$contains$6dc00deccaf89e6e(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *, struct _jc_java_nio_charset_Charset$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_charset_CharsetDecoder$object *_jc_gnu_java_nio_charset_US__5fASCII$method$newDecoder$a8155f7e01d3e07a(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_charset_CharsetEncoder$object *_jc_gnu_java_nio_charset_US__5fASCII$method$newEncoder$d60e26d796f39211(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_US__5fASCII$method_info$contains$6dc00deccaf89e6e;
extern _jc_method _jc_gnu_java_nio_charset_US__5fASCII$method_info$newDecoder$a8155f7e01d3e07a;
extern _jc_method _jc_gnu_java_nio_charset_US__5fASCII$method_info$newEncoder$d60e26d796f39211;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_US__5fASCII$vmethods {
	jboolean	(*contains$6dc00deccaf89e6e)(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *, struct _jc_java_nio_charset_Charset$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_charset_CharsetDecoder$object	*(*newDecoder$a8155f7e01d3e07a)(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_charset_CharsetEncoder$object	*(*newEncoder$d60e26d796f39211)(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_charset_US__5fASCII$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_Charset$vmethods	java_nio_charset_Charset;
	_jc_gnu_java_nio_charset_US__5fASCII$vmethods	gnu_java_nio_charset_US__5fASCII;
};

// Vtype
struct _jc_gnu_java_nio_charset_US__5fASCII$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_US__5fASCII$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_US__5fASCII$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_US__5fASCII$refs {
    _jc_gnu_java_nio_charset_US__5fASCII$sub_refs	gnu_java_nio_charset_US__5fASCII;
    _jc_java_nio_charset_Charset$sub_refs	java_nio_charset_Charset;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_US__5fASCII$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_US__5fASCII$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_Charset$sub_nonrefs	java_nio_charset_Charset;
    _jc_gnu_java_nio_charset_US__5fASCII$sub_nonrefs	gnu_java_nio_charset_US__5fASCII;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_US__5fASCII$object {
	_jc_gnu_java_nio_charset_US__5fASCII$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_US__5fASCII$vtype	*vtype;
	_jc_gnu_java_nio_charset_US__5fASCII$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_US__5fASCII$vtype _jc_gnu_java_nio_charset_US__5fASCII$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_US__5fASCII, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_US__5fASCII$class_object;

#endif	/* _JC_gnu_java_nio_charset_US__5fASCII_H_ */
